@@ -6,8 +6,8 @@ set -e -u -x
 mkdir build
 cd build
 cmake .. -DCMAKE_INCLUDE_PATH=$CACHE_DIR/usr/lib \
-         -DUTOX_STATIC=ON \
-         -DTOXCORE_STATIC=ON \
+         -DSTATIC_ALL=ON \
+         -DSTATIC_TOXCORE=ON \
          -DCMAKE_COLOR_MAKEFILE=ON \
          -DENABLE_TESTS=ON \
          -DENABLE_WERROR=ON \
