@@ -12,8 +12,8 @@ cmake .. \
     -DCMAKE_INCLUDE_PATH="$CACHE_DIR/usr/include" \
     -DCMAKE_LIBRARY_PATH="$CACHE_DIR/usr/lib" \
     -DENABLE_FILTERAUDIO=OFF \
-    -DUTOX_STATIC=ON \
-    -DTOXCORE_STATIC=ON \
+    -DSTATIC_ALL=ON \
+    -DSTATIC_TOXCORE=ON \
     -DENABLE_TESTS=OFF \
     -DENABLE_WERROR=OFF
 
