@@ -210,9 +210,6 @@ msgstr("Fortgeschritten")
 msgid(NOTIFICATIONS_BUTTON)
 msgstr("Benachrichtigungen")
 
-msgid(AUTO_UPDATE)
-msgstr("uTox automatisch aktualisieren")
-
 msgid(PROFILE_SETTINGS)
 msgstr("Profileinstellungen")
 
