@@ -253,19 +253,26 @@ void flist_re_scale(void) {
 }
 
 bool friend_matches_search_string(FRIEND *f, char *str) {
-    return !str || strstr_case(f->name, str) || (f->alias && strstr_case(f->alias, str));
+    return !str
+           || strstr_case(f->name, str)
+           || (f->alias && strstr_case(f->alias, str))
+           || strstr_case(f->id_str, str);
 }
 
 void flist_update_shown_list(void) {
     uint32_t j; // index in shown_list array
     for (uint32_t i = j = 0; i < itemcount; i++) {
         ITEM  *it = &item[i];
-        if (it->type == ITEM_FRIEND) {
-            FRIEND *f = get_friend(it->id_number);
-            if ((!filter || f->online) && friend_matches_search_string(f, search_string)) {
+        if (it->type != ITEM_FRIEND) {
+            shown_list[j++] = i;
+            continue;
+        }
+        FRIEND *f = get_friend(it->id_number);
+        if (search_string) {
+            if (friend_matches_search_string(f, search_string)) {
                 shown_list[j++] = i;
             }
-        } else {
+        } else if ((!filter || f->online || f->unread_msg || it == selected_item)) {
             shown_list[j++] = i;
         }
     }
@@ -338,7 +345,7 @@ void flist_search(char *str) {
 static void change_tab(int offset) {
     /* Pg-Up/Dn broke on the create group icon,
      * remoing this if seems to work but I don't know what it was doing here
-     * so I commented it incase it breaks stuff...  */
+     * so I commented it in case it breaks stuff...  */
     // if (selected_item->type == ITEM_FRIEND ||
     // selected_item->type == ITEM_GROUP) {
     unsigned int index = find_item_shown_index(selected_item);
@@ -357,6 +364,19 @@ void flist_next_tab(void) {
     change_tab(1);
 }
 
+void flist_first_tab(void) {
+    flist_selectchat(0);
+}
+
+void flist_last_tab(void) {
+    if (showncount < 2) {
+        /* No friends and groups in the list, nothing to do */
+        return;
+    }
+
+    flist_selectchat(showncount - 2);
+}
+
 /* TODO: move this out of here!
  * maybe to ui.c ? */
 static int  current_width; // I know, but I'm in a hurry, so I'll fix this later
@@ -602,6 +622,8 @@ static void show_page(ITEM *i) {
     selected_item = i;
 
     addfriend_status = 0;
+
+    flist_update_shown_list();
 }
 
 void flist_start(void) {
