@@ -36,6 +36,8 @@
 
 #define UTOX_MAX_BACKLOG_MESSAGES 256
 
+pthread_mutex_t messages_lock;
+
 /** Appends a messages from self or friend to the message list;
  * will realloc or trim messages as needed;
  *
@@ -189,10 +191,16 @@ static uint32_t message_add(MESSAGES *m, MSG_HEADER *msg) {
 
     message_updateheight(m, msg);
 
-    if (flist_get_groupchat() && m->is_groupchat && flist_get_groupchat() == get_group(m->id)) {
-        m->panel.content_scroll->content_height = m->height;
-    } else if (flist_get_friend() && flist_get_friend()->number == get_friend(m->id)->number) {
-        m->panel.content_scroll->content_height = m->height;
+    if (m->is_groupchat) {
+        const GROUPCHAT *groupchat = flist_get_groupchat();
+        if (groupchat && groupchat == get_group(m->id)) {
+            m->panel.content_scroll->content_height = m->height;
+        }
+    } else {
+        const FRIEND *friend = flist_get_friend();
+        if (friend && friend == get_friend(m->id)) {
+            m->panel.content_scroll->content_height = m->height;
+        }
     }
 
     pthread_mutex_unlock(&messages_lock);
@@ -965,10 +973,10 @@ static void messages_draw_filetransfer(MESSAGES *m, MSG_FILE *file, uint32_t i,
     drawtextrange(dx + SCALE(10), wbound - SCALE(10), y + SCALE(6), ft_text, ft_text_length);
 }
 
-/* This is a bit hacky, and likely would benifit from being moved to a whole new section including seperating
+/* This is a bit hacky, and likely would benefit from being moved to a whole new section including separating
  * group messages/functions from friend messages and functions from inside ui.c.
  *
- * Idealy group and friend messages wouldn't even need to know about eachother.   */
+ * Ideally group and friend messages wouldn't even need to know about each other.   */
 static int messages_draw_group(MESSAGES *m, MSG_HEADER *msg, uint32_t curr_msg_i, int x, int y, int width, int height) {
     uint32_t h1 = UINT32_MAX, h2 = UINT32_MAX;
     if ((m->sel_start_msg > curr_msg_i && m->sel_end_msg > curr_msg_i)
@@ -1801,7 +1809,7 @@ bool messages_char(uint32_t ch) {
     }
 
     switch (ch) {
-        // TODO: probabaly need to fix this section :< m->panel.content scroll is likely to be wrong.
+        // TODO: probably need to fix this section :< m->panel.content scroll is likely to be wrong.
         case KEY_PAGEUP: {
             SCROLLABLE *scroll = m->panel.content_scroll;
             scroll->d -= 0.25; // TODO: Change to a full chat-screen height.
@@ -1821,6 +1829,16 @@ bool messages_char(uint32_t ch) {
 
             return true;
         }
+
+        case KEY_HOME: {
+            m->panel.content_scroll->d = 0.0;
+            return true;
+        }
+
+        case KEY_END: {
+            m->panel.content_scroll->d = 1.0;
+            return true;
+        }
     }
 
     return false;
