@@ -18,7 +18,6 @@
 #include "../text.h"
 #include "../theme.h"
 #include "../tox.h"
-#include "../updater.h"
 #include "../utox.h"
 
 #include "../av/utox_av.h"
@@ -42,7 +41,28 @@
 #include <signal.h>
 #include <sys/wait.h>
 
-bool hidden = false;
+Atom wm_protocols, wm_delete_window;
+Atom XA_CLIPBOARD, XA_NET_NAME, XA_UTF8_STRING, targets, XA_INCR;
+Atom XdndAware, XdndEnter, XdndLeave, XdndPosition, XdndStatus, XdndDrop, XdndSelection, XdndDATA, XdndActionCopy;
+Atom XA_URI_LIST, XA_PNG_IMG;
+Atom XRedraw;
+
+Picture bitmap[BM_ENDMARKER];
+Cursor  cursors[8];
+
+uint8_t pointergrab;
+
+bool     _redraw;
+
+XImage *screen_image;
+
+void *libgtk;
+
+struct utox_clipboard clipboard;
+struct utox_primary primary;
+struct utox_pastebuf pastebuf;
+
+static bool hidden = false;
 
 XIC xic = NULL;
 static XSizeHints *xsh = NULL;
@@ -93,10 +113,8 @@ void init_ptt(void) {
 
 
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__DragonFly__) || defined(__FreeBSD__)
 #include <linux/input.h>
-#elif defined(__DragonFly__) || defined(__FreeBSD__)
-#include <dev/misc/evdev/input.h>
 #endif
 
 #if defined(__linux__) || defined(__DragonFly__) || defined(__FreeBSD__)
@@ -120,7 +138,7 @@ static bool linux_check_ptt(void) {
             return false;
         }
     }
-    /* Okay nope, lets' fallback to xinput... *pouts*
+    /* Okay nope, let's fallback to xinput... *pouts*
      * Fall back to Querying the X for the current keymap. */
     ptt_key       = XKeysymToKeycode(display, XK_Control_L);
     char keys[32] = { 0 };
@@ -384,7 +402,7 @@ void formaturilist(char *out, const char *in, size_t len) {
     // out[len - removed - 1] = '\n';
 }
 
-// TODO(robinli): Go over this function and see if either len or size are removeable.
+// TODO(robinli): Go over this function and see if either len or size are removable.
 void pastedata(void *data, Atom type, size_t len, bool select) {
 
     size_t size = len;
@@ -519,7 +537,7 @@ NATIVE_IMAGE *utox_image_to_native(const UTOX_IMAGE data, size_t size, uint16_t
 
     NATIVE_IMAGE *image = malloc(sizeof(NATIVE_IMAGE));
     if (image == NULL) {
-        LOG_ERR("utox_image_to_native", "Could mot allocate memory for image." );
+        LOG_ERR("utox_image_to_native", "Could not allocate memory for image." );
         return NULL;
     }
     image->rgb   = rgb;
@@ -578,7 +596,7 @@ void setscale(void) {
 
     if (settings.window_width > (uint32_t)SCALE(MAIN_WIDTH) &&
         settings.window_height > (uint32_t)SCALE(MAIN_HEIGHT)) {
-        /* wont get a resize event, call this manually */
+        /* won't get a resize event, call this manually */
         ui_size(settings.window_width, settings.window_height);
     }
 }
@@ -702,10 +720,8 @@ int main(int argc, char *argv[]) {
 
     int8_t should_launch_at_startup;
     int8_t set_show_window;
-    bool   skip_updater;
     bool allow_root;
     parse_args(argc, argv,
-               &skip_updater,
                &should_launch_at_startup,
                &set_show_window,
                &allow_root);
@@ -722,11 +738,6 @@ int main(int argc, char *argv[]) {
         LOG_NOTE("XLIB", "Start on boot not supported on this OS, please use your distro suggested method!\n");
     }
 
-    if (skip_updater == true) {
-        LOG_ERR("XLIB", "Disabling the updater is not supported on this OS. "
-                        "Updates are managed by your distro's package manager.\n");
-    }
-
     LOG_INFO("XLIB MAIN", "Setting theme to:\t%d", settings.theme);
     theme_load(settings.theme);
 
